=============================
 Querying for data file URLs
=============================

.. automodule:: gwosc.locate

.. rubric:: Functions
   :class: h2

.. automodsumm:: gwosc.locate
   :toctree: reference/
